/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.cropcircle;

/**
 *  enum for defining fields in the crop circle files
 *  
 *  @author Merijn Zengers
 */


public enum CropcircleASC340FileDescription {
        /* Longitude of measured cropcircle coordinate */
	LONGITUDE(), //12 0003.8513480
	
        /* Latitude of measured cropcircle coordinate */
        LATITUDE(), //12 0051.5193244
        
        /*  */
	FIX_TYPE(), //1 4
        
        /* UTC Standard time */
	UTC_TIME(), //9 042352.06
              
        /* Speed of vehicle at the moment this coordinate is measured. Unit? KM/h? Miles/h? */
	SPEED(), //3 0.0
        
        /* Coure of the sensor */
	COURSE(), //5 175.8
        
        /* Number of the sensor. (It is possible that more then one sensor is active at the same time.) */
	SENSOR(), //1 1
        
        /* Vegetation Index calculated with the formula: (R2-R1)/(R2+R1) Rounded on 3 decimals. */
	VI1(), //6  0.000
        
        /* Vegetation Index calculated with the formula: (R2-R3)/(R2+R3) Rounded on 3 decimals. */
	VI2(), //7 999.000
        
        /* Reflection measurement, done on a wavelength of 670nm */
	R1(), //8 999.0000
        
        /* Reflection measurement, done on a wavelength of 730nm */
	R2(), //8 999.0000
        
        /* Reflection measurement, done on a wavelength of 780nm */
	R3(), //8 999.0000
        
        /**/
	APP_RATE(); //1

	
	private CropcircleASC340FileDescription(){
		
	}
}
